@@ -108,23 +108,74 @@ namespace Gecode {
   }
 
   void
-  assign(Home home, const FloatVarArgs& x, FloatAssign fa,
+  assign(Home home, const FloatVarArgs& x,
+         FloatVarBranch vars, FloatAssign vals,
          FloatBranchFilter bf,
          FloatVarValPrint vvp) {
     using namespace Float;
     if (home.failed()) return;
     ViewArray<FloatView> xv(home,x);
     ViewSel<FloatView>* vs[1] = {
-      new (home) ViewSelNone<FloatView>(home,FLOAT_VAR_NONE())
+      new (home) ViewSelNone<FloatView>(home,vars)
     };
     postviewvalbrancher<FloatView,1,FloatNumBranch,1>
-      (home,xv,vs,Branch::valselcommit(home,fa),bf,vvp);
+      (home,xv,vs,Branch::valselcommit(home,vals),bf,vvp);
   }
 
   void
-  assign(Home home, FloatVar x, FloatAssign fa, FloatVarValPrint vvp) {
+  assign(Home home, const FloatVarArgs& x,
+         TieBreak<FloatVarBranch> vars, FloatAssign vals,
+         FloatBranchFilter bf,
+         FloatVarValPrint vvp) {
+    using namespace Float;
+    if (home.failed()) return;
+    vars.a.expand(home,x);
+    if ((vars.a.select() == FloatVarBranch::SEL_NONE) ||
+        (vars.a.select() == FloatVarBranch::SEL_RND))
+      vars.b = FLOAT_VAR_NONE();
+    vars.b.expand(home,x);
+    if ((vars.b.select() == FloatVarBranch::SEL_NONE) ||
+        (vars.b.select() == FloatVarBranch::SEL_RND))
+      vars.c = FLOAT_VAR_NONE();
+    vars.c.expand(home,x);
+    if ((vars.c.select() == FloatVarBranch::SEL_NONE) ||
+        (vars.c.select() == FloatVarBranch::SEL_RND))
+      vars.d = FLOAT_VAR_NONE();
+    vars.d.expand(home,x);
+    if (vars.b.select() == FloatVarBranch::SEL_NONE) {
+      assign(home,x,vars.a,vals,bf,vvp);
+    } else {
+      ViewArray<FloatView> xv(home,x);
+      ValSelCommitBase<FloatView,FloatNumBranch>*
+        vsc = Branch::valselcommit(home,vals);
+      if (vars.c.select() == FloatVarBranch::SEL_NONE) {
+        ViewSel<FloatView>* vs[2] = {
+          Branch::viewsel(home,vars.a),Branch::viewsel(home,vars.b)
+        };
+        postviewvalbrancher<FloatView,2,FloatNumBranch,1>
+          (home,xv,vs,vsc,bf,vvp);
+      } else if (vars.d.select() == FloatVarBranch::SEL_NONE) {
+        ViewSel<FloatView>* vs[3] = {
+          Branch::viewsel(home,vars.a),Branch::viewsel(home,vars.b),
+          Branch::viewsel(home,vars.c)
+        };
+        postviewvalbrancher<FloatView,3,FloatNumBranch,1>
+          (home,xv,vs,vsc,bf,vvp);
+      } else {
+        ViewSel<FloatView>* vs[4] = {
+          Branch::viewsel(home,vars.a),Branch::viewsel(home,vars.b),
+          Branch::viewsel(home,vars.c),Branch::viewsel(home,vars.d)
+        };
+        postviewvalbrancher<FloatView,4,FloatNumBranch,1>
+          (home,xv,vs,vsc,bf,vvp);
+      }
+    }
+  }
+
+  void
+  assign(Home home, FloatVar x, FloatAssign vals, FloatVarValPrint vvp) {
     FloatVarArgs xv(1); xv[0]=x;
-    assign(home, xv, fa, nullptr, vvp);
+    assign(home, xv, FLOAT_VAR_NONE(), vals, nullptr, vvp);
   }
 
 }
