@@ -244,6 +244,16 @@ namespace Gecode { namespace Float {
   std::basic_ostream<Char,Traits>&
   operator <<(std::basic_ostream<Char,Traits>& os, const MinusView& x);
 
+  /** \name View comparison
+   *  \relates Gecode::Float::MinusView
+   */
+  //@{
+  /// Test whether views \a x and \a y are the same
+  bool operator ==(const MinusView& x, const MinusView& y);
+  /// Test whether views \a x and \a y are not the same
+  bool operator !=(const MinusView& x, const MinusView& y);
+  //@}
+
 
   /**
    * \brief OffsetView float view
@@ -347,6 +357,12 @@ namespace Gecode { namespace Float {
     //@{
     void update(Space& home, OffsetView& y);
     //@}
+
+    /// \name Ordering
+    //@{
+    /// Whether this view comes before view \a y (arbitray order)
+    bool operator <(const OffsetView& y) const;
+    //@}
   };
 
   /**
@@ -357,6 +373,16 @@ namespace Gecode { namespace Float {
   std::basic_ostream<Char,Traits>&
   operator <<(std::basic_ostream<Char,Traits>& os, const OffsetView& x);
 
+  /** \name View comparison
+   *  \relates Gecode::Float::OffsetView
+   */
+  //@{
+  /// Test whether views \a x and \a y are the same
+  bool operator ==(const OffsetView& x, const OffsetView& y);
+  /// Test whether views \a x and \a y are not the same
+  bool operator !=(const OffsetView& x, const OffsetView& y);
+  //@}
+
   /**
    * \brief Scale float view
    *
@@ -460,6 +486,12 @@ namespace Gecode { namespace Float {
     //@{
     void update(Space& home, ScaleView& y);
     //@}
+
+    /// \name Ordering
+    //@{
+    /// Whether this view comes before view \a y (arbitray order)
+    bool operator <(const ScaleView& y) const;
+    //@}
   };
 
   /**
@@ -470,7 +502,17 @@ namespace Gecode { namespace Float {
   std::basic_ostream<Char,Traits>&
   operator <<(std::basic_ostream<Char,Traits>& os, const ScaleView& x);
 
-} }
+  /** \name View comparison
+   *  \relates Gecode::Float::ScaleView
+   */
+  //@{
+  /// Test whether views \a x and \a y are the same
+  bool operator ==(const ScaleView& x, const ScaleView& y);
+  /// Test whether views \a x and \a y are not the same
+  bool operator !=(const ScaleView& x, const ScaleView& y);
+  //@}
+
+}}
 
 #include <gecode/float/var/float.hpp>
 #include <gecode/float/view/float.hpp>
