@@ -35,22 +35,13 @@
 
 namespace Gecode {
 
-  IntArgs::IntArgs(int n, int e0, ...) : PrimArgArray<int>(n) {
-    va_list args;
-    va_start(args, e0);
-    a[0] = e0;
-    for (int i = 1; i < n; i++)
-      a[i] = va_arg(args,int);
-    va_end(args);
-  }
-
   IntVarArray::IntVarArray(Space& home, int n, int min, int max)
     : VarArray<IntVar>(home,n) {
     Int::Limits::check(min,"IntVarArray::IntVarArray");
     Int::Limits::check(max,"IntVarArray::IntVarArray");
     if (min > max)
       throw Int::VariableEmptyDomain("IntVarArray::IntVarArray");
-    for (int i = size(); i--; )
+    for (int i=0; i<size(); i++)
       x[i]._init(home,min,max);
   }
 
@@ -60,7 +51,7 @@ namespace Gecode {
     Int::Limits::check(s.max(),"IntVarArray::IntVarArray");
     if (s.size() == 0)
       throw Int::VariableEmptyDomain("IntVarArray::IntVarArray");
-    for (int i = size(); i--; )
+    for (int i=0; i<size(); i++)
       x[i]._init(home,s);
   }
 
@@ -70,7 +61,7 @@ namespace Gecode {
       throw Int::NotZeroOne("BoolVarArray::BoolVarArray");
     if (min > max)
       throw Int::VariableEmptyDomain("BoolVarArray::BoolVarArray");
-    for (int i = size(); i--; )
+    for (int i=0; i<size(); i++)
       x[i]._init(home,min,max);
   }
 
@@ -80,7 +71,7 @@ namespace Gecode {
     Int::Limits::check(max,"IntVarArgs::IntVarArgs");
     if (min > max)
       throw Int::VariableEmptyDomain("IntVarArgs::IntVarArgs");
-    for (int i = size(); i--; )
+    for (int i=0; i<size(); i++)
       a[i]._init(home,min,max);
   }
 
@@ -90,7 +81,7 @@ namespace Gecode {
     Int::Limits::check(s.max(),"IntVarArgs::IntVarArgs");
     if (s.size() == 0)
       throw Int::VariableEmptyDomain("IntVarArgs::IntVarArgs");
-    for (int i = size(); i--; )
+    for (int i=0; i<size(); i++)
       a[i]._init(home,s);
   }
 
@@ -100,7 +91,7 @@ namespace Gecode {
       throw Int::NotZeroOne("BoolVarArgs::BoolVarArgs");
     if (min > max)
       throw Int::VariableEmptyDomain("BoolVarArgs::BoolVarArgs");
-    for (int i = size(); i--; )
+    for (int i=0; i<size(); i++)
       a[i]._init(home,min,max);
   }
 
