@@ -39,30 +39,38 @@ namespace Gecode {
    */
 
   forceinline
-  IntArgs::IntArgs(void) : PrimArgArray<int>(0) {}
+  IntArgs::IntArgs(void) : ArgArray<int>(0) {}
 
   forceinline
-  IntArgs::IntArgs(int n) : PrimArgArray<int>(n) {}
+  IntArgs::IntArgs(int n) : ArgArray<int>(n) {}
 
   forceinline
   IntArgs::IntArgs(const SharedArray<int>& x)
-    : PrimArgArray<int>(x.size()) {
-    for (int i=x.size(); i--;)
+    : ArgArray<int>(x.size()) {
+    for (int i=0; i<x.size(); i++)
       a[i] = x[i];
   }
+
   forceinline
   IntArgs::IntArgs(const std::vector<int>& x)
-  : PrimArgArray<int>(x) {}
+    : ArgArray<int>(x) {}
+
+  forceinline
+  IntArgs::IntArgs(std::initializer_list<int> x)
+    : ArgArray<int>(x) {}
+
   template<class InputIterator>
   forceinline
   IntArgs::IntArgs(InputIterator first, InputIterator last)
-  : PrimArgArray<int>(first,last) {}
+    : ArgArray<int>(first,last) {}
 
   forceinline
-  IntArgs::IntArgs(int n, const int* e) : PrimArgArray<int>(n, e) {}
+  IntArgs::IntArgs(int n, const int* e)
+    : ArgArray<int>(n, e) {}
 
   forceinline
-  IntArgs::IntArgs(const PrimArgArray<int>& a) : PrimArgArray<int>(a) {}
+  IntArgs::IntArgs(const ArgArray<int>& a)
+    : ArgArray<int>(a) {}
 
   forceinline IntArgs
   IntArgs::create(int n, int start, int inc) {
@@ -72,6 +80,65 @@ namespace Gecode {
     return r;
   }
 
+
+  forceinline
+  IntVarArgs::IntVarArgs(void) {}
+
+  forceinline
+  IntVarArgs::IntVarArgs(int n)
+    : VarArgArray<IntVar>(n) {}
+
+  forceinline
+  IntVarArgs::IntVarArgs(const IntVarArgs& a)
+    : VarArgArray<IntVar>(a) {}
+
+  forceinline
+  IntVarArgs::IntVarArgs(const VarArray<IntVar>& a)
+    : VarArgArray<IntVar>(a) {}
+
+  forceinline
+  IntVarArgs::IntVarArgs(const std::vector<IntVar>& a)
+    : VarArgArray<IntVar>(a) {}
+
+  forceinline
+  IntVarArgs::IntVarArgs(std::initializer_list<IntVar> a)
+    : VarArgArray<IntVar>(a) {}
+
+  template<class InputIterator>
+  forceinline
+  IntVarArgs::IntVarArgs(InputIterator first, InputIterator last)
+    : VarArgArray<IntVar>(first,last) {}
+
+
+  forceinline
+  BoolVarArgs::BoolVarArgs(void) {}
+
+  forceinline
+  BoolVarArgs::BoolVarArgs(int n)
+    : VarArgArray<BoolVar>(n) {}
+
+  forceinline
+  BoolVarArgs::BoolVarArgs(const BoolVarArgs& a)
+    : VarArgArray<BoolVar>(a) {}
+
+  forceinline
+  BoolVarArgs::BoolVarArgs(const VarArray<BoolVar>& a)
+    : VarArgArray<BoolVar>(a) {}
+
+  forceinline
+  BoolVarArgs::BoolVarArgs(const std::vector<BoolVar>& a)
+    : VarArgArray<BoolVar>(a) {}
+
+  forceinline
+  BoolVarArgs::BoolVarArgs(std::initializer_list<BoolVar> a)
+    : VarArgArray<BoolVar>(a) {}
+
+  template<class InputIterator>
+  forceinline
+  BoolVarArgs::BoolVarArgs(InputIterator first, InputIterator last)
+    : VarArgArray<BoolVar>(first,last) {}
+
+
   forceinline
   IntVarArray::IntVarArray(void) {}
 
