@@ -120,7 +120,7 @@ namespace Gecode { namespace Int { namespace Bool {
       return NaryOrTrue<VX>::post(home,x);
     if ((x.size() == 1) && (y.size() == 1)) {
       return BinOrTrue<VX,VY>::post(home,x[0],y[0]);
-    } else if (!x.shared(y)) {
+    } else if (!shared(x,y)) {
       (void) new (home) ClauseTrue(home,x,y);
     }
     return ES_OK;
@@ -160,7 +160,7 @@ namespace Gecode { namespace Int { namespace Bool {
         }
       // All x-views have been assigned!
       ViewArray<VY> z(home,y.size()+1);
-      for (int i=y.size(); i--; )
+      for (int i=0; i<y.size(); i++)
         z[i]=y[i];
       z[y.size()] = x1;
       GECODE_REWRITE(p,(NaryOrTrue<VY>::post(home(p),z)));
@@ -244,13 +244,13 @@ namespace Gecode { namespace Int { namespace Bool {
   template<class VX, class VY>
   inline ExecStatus
   Clause<VX,VY>::post(Home home, ViewArray<VX>& x, ViewArray<VY>& y, VX z) {
-    assert(!x.shared() && !y.shared());
+    assert(!shared(x) && !shared(y));
     if (z.one())
       return ClauseTrue<VX,VY>::post(home,x,y);
     if (z.zero()) {
-      for (int i=x.size(); i--; )
+      for (int i=0; i<x.size(); i++)
         GECODE_ME_CHECK(x[i].zero(home));
-      for (int i=y.size(); i--; )
+      for (int i=0; i<y.size(); i++)
         GECODE_ME_CHECK(y[i].zero(home));
       return ES_OK;
     }
@@ -274,7 +274,7 @@ namespace Gecode { namespace Int { namespace Bool {
       return NaryOr<VX,VX>::post(home,x,z);
     if ((x.size() == 1) && (y.size() == 1)) {
       return Or<VX,VY,VX>::post(home,x[0],y[0],z);
-    } else if (x.shared(y)) {
+    } else if (shared(x,y)) {
       GECODE_ME_CHECK(z.one_none(home));
     } else {
       (void) new (home) Clause<VX,VY>(home,x,y,z);
@@ -328,12 +328,12 @@ namespace Gecode { namespace Int { namespace Bool {
     z.reschedule(home,*this,PC_BOOL_VAL);
     if (n_zero == x.size() + y.size())
       VX::schedule(home,*this,ME_BOOL_VAL);
-    for (int i=x.size(); i--; )
+    for (int i=0; i<x.size(); i++)
       if (x[i].one()) {
         VX::schedule(home,*this,ME_BOOL_VAL);
         return;
       }
-    for (int i=y.size(); i--; )
+    for (int i=0; i<y.size(); i++)
       if (y[i].one()) {
         VX::schedule(home,*this,ME_BOOL_VAL);
         return;
@@ -346,9 +346,9 @@ namespace Gecode { namespace Int { namespace Bool {
     if (z.one())
       GECODE_REWRITE(*this,(ClauseTrue<VX,VY>::post(home(*this),x,y)));
     if (z.zero()) {
-      for (int i = x.size(); i--; )
+      for (int i=0; i<x.size(); i++)
         GECODE_ME_CHECK(x[i].zero(home));
-      for (int i = y.size(); i--; )
+      for (int i=0; i<y.size(); i++)
         GECODE_ME_CHECK(y[i].zero(home));
       c.dispose(home);
     } else if (n_zero == x.size() + y.size()) {
