@@ -36,7 +36,8 @@ namespace Gecode { namespace Int { namespace Branch {
   // Minimum merit
   template<class View>
   forceinline
-  MeritMin<View>::MeritMin(Space& home, const VarBranch<Var>& vb)
+  MeritMin<View>::MeritMin
+    (Space& home, const VarBranch<MeritMin<View>::Var>& vb)
     : MeritBase<View,int>(home,vb) {}
   template<class View>
   forceinline
@@ -51,7 +52,8 @@ namespace Gecode { namespace Int { namespace Branch {
   // Maximum merit
   template<class View>
   forceinline
-  MeritMax<View>::MeritMax(Space& home, const VarBranch<Var>& vb)
+  MeritMax<View>::MeritMax
+    (Space& home, const VarBranch<MeritMax<View>::Var>& vb)
     : MeritBase<View,int>(home,vb) {}
   template<class View>
   forceinline
@@ -66,7 +68,8 @@ namespace Gecode { namespace Int { namespace Branch {
   // Size merit
   template<class View>
   forceinline
-  MeritSize<View>::MeritSize(Space& home, const VarBranch<Var>& vb)
+  MeritSize<View>::MeritSize
+    (Space& home, const VarBranch<MeritSize<View>::Var>& vb)
     : MeritBase<View,unsigned int>(home,vb) {}
   template<class View>
   forceinline
@@ -81,7 +84,8 @@ namespace Gecode { namespace Int { namespace Branch {
   // Degree over size merit
   template<class View>
   forceinline
-  MeritDegreeSize<View>::MeritDegreeSize(Space& home, const VarBranch<Var>& vb)
+  MeritDegreeSize<View>::MeritDegreeSize
+    (Space& home, const VarBranch<MeritDegreeSize<View>::Var>& vb)
     : MeritBase<View,double>(home,vb) {}
   template<class View>
   forceinline
@@ -96,7 +100,8 @@ namespace Gecode { namespace Int { namespace Branch {
   // AFC over size merit
   template<class View>
   forceinline
-  MeritAFCSize<View>::MeritAFCSize(Space& home, const VarBranch<Var>& vb)
+  MeritAFCSize<View>::MeritAFCSize
+    (Space& home, const VarBranch<MeritAFCSize<View>::Var>& vb)
     : MeritBase<View,double>(home,vb), afc(vb.afc()) {}
   template<class View>
   forceinline
@@ -122,8 +127,8 @@ namespace Gecode { namespace Int { namespace Branch {
   // Action over size merit
   template<class View>
   forceinline
-  MeritActionSize<View>::MeritActionSize(Space& home,
-                                         const VarBranch<Var>& vb)
+  MeritActionSize<View>::MeritActionSize
+  (Space& home, const VarBranch<MeritActionSize<View>::Var>& vb)
     : MeritBase<View,double>(home,vb), action(vb.action()) {}
   template<class View>
   forceinline
@@ -148,8 +153,8 @@ namespace Gecode { namespace Int { namespace Branch {
   // CHB over size merit
   template<class View>
   forceinline
-  MeritCHBSize<View>::MeritCHBSize(Space& home,
-                                   const VarBranch<Var>& vb)
+  MeritCHBSize<View>::MeritCHBSize
+  (Space& home, const VarBranch<MeritCHBSize<View>::Var>& vb)
     : MeritBase<View,double>(home,vb), chb(vb.chb()) {}
   template<class View>
   forceinline
@@ -174,7 +179,8 @@ namespace Gecode { namespace Int { namespace Branch {
   // Minimum regret merit
   template<class View>
   forceinline
-  MeritRegretMin<View>::MeritRegretMin(Space& home, const VarBranch<Var>& vb)
+  MeritRegretMin<View>::MeritRegretMin
+  (Space& home, const VarBranch<MeritRegretMin<View>::Var>& vb)
     : MeritBase<View,unsigned int>(home,vb) {}
   template<class View>
   forceinline
@@ -189,7 +195,8 @@ namespace Gecode { namespace Int { namespace Branch {
   // Maximum regret merit
   template<class View>
   forceinline
-  MeritRegretMax<View>::MeritRegretMax(Space& home, const VarBranch<Var>& vb)
+  MeritRegretMax<View>::MeritRegretMax
+  (Space& home, const VarBranch<MeritRegretMax<View>::Var>& vb)
     : MeritBase<View,unsigned int>(home,vb) {}
   template<class View>
   forceinline
