@@ -35,7 +35,8 @@ namespace Gecode { namespace Int { namespace Branch {
 
   template<class View>
   forceinline
-  ValCommitEq<View>::ValCommitEq(Space& home, const ValBranch<Var>& vb)
+  ValCommitEq<View>::ValCommitEq
+  (Space& home, const ValBranch<ValCommitEq<View>::Var>& vb)
     : ValCommit<View,int>(home,vb) {}
   template<class View>
   forceinline
@@ -64,7 +65,8 @@ namespace Gecode { namespace Int { namespace Branch {
 
   template<class View>
   forceinline
-  ValCommitLq<View>::ValCommitLq(Space& home, const ValBranch<Var>& vb)
+  ValCommitLq<View>::ValCommitLq
+  (Space& home, const ValBranch<ValCommitLq<View>::Var>& vb)
     : ValCommit<View,int>(home,vb) {}
   template<class View>
   forceinline
@@ -93,7 +95,8 @@ namespace Gecode { namespace Int { namespace Branch {
 
   template<class View>
   forceinline
-  ValCommitGq<View>::ValCommitGq(Space& home, const ValBranch<Var>& vb)
+  ValCommitGq<View>::ValCommitGq
+  (Space& home, const ValBranch<ValCommitGq<View>::Var>& vb)
     : ValCommit<View,int>(home,vb) {}
   template<class View>
   forceinline
@@ -122,7 +125,8 @@ namespace Gecode { namespace Int { namespace Branch {
 
   template<class View>
   forceinline
-  ValCommitGr<View>::ValCommitGr(Space& home, const ValBranch<Var>& vb)
+  ValCommitGr<View>::ValCommitGr
+  (Space& home, const ValBranch<ValCommitGr<View>::Var>& vb)
     : ValCommit<View,int>(home,vb) {}
   template<class View>
   forceinline
