@@ -42,7 +42,7 @@ namespace Gecode {
     if (c.size() == 0)
       throw TooFewArguments("Int::element");
     GECODE_POST;
-    for (int i = c.size(); i--; )
+    for (int i=0; i<c.size(); i++)
       Limits::check(c[i],"Int::element");
     GECODE_ES_FAIL((Element::post_int<IntView,IntView>(home,c,x0,x1)));
   }
@@ -54,7 +54,7 @@ namespace Gecode {
     if (c.size() == 0)
       throw TooFewArguments("Int::element");
     GECODE_POST;
-    for (int i = c.size(); i--; )
+    for (int i=0; i<c.size(); i++)
       Limits::check(c[i],"Int::element");
     GECODE_ES_FAIL((Element::post_int<IntView,BoolView>(home,c,x0,x1)));
   }
@@ -67,7 +67,7 @@ namespace Gecode {
       throw TooFewArguments("Int::element");
     Limits::check(x1,"Int::element");
     GECODE_POST;
-    for (int i = c.size(); i--; )
+    for (int i=0; i<c.size(); i++)
       Limits::check(c[i],"Int::element");
     ConstIntView cx1(x1);
     GECODE_ES_FAIL(
