@@ -37,151 +37,6 @@
 
 namespace Gecode { namespace Int { namespace Extensional {
 
-  template<class IndexType>
-  forceinline
-  BitSet<IndexType>::BitSet(Space& home, unsigned int n)
-    : _limit(static_cast<IndexType>(n)), 
-      index(home.alloc<IndexType>(n)),
-      bits(home.alloc<BitSetData>(n)) {
-    // Set all bits in all words (including the last)
-    for (IndexType i=_limit; i--; ) {
-      bits[i].init(true);
-      index[i] = i;
-    }
-  }
-
-  template<class IndexType>
-  template<class OldIndexType>
-  forceinline
-  BitSet<IndexType>::BitSet(Space& home,
-                            const BitSet<OldIndexType>& bs)
-    : _limit(bs._limit),
-      index(home.alloc<IndexType>(_limit)),
-      bits(home.alloc<BitSetData>(_limit)) {
-    assert(_limit > 0U);
-    for (IndexType i = _limit; i--; ) {
-      bits[i] = bs.bits[i];
-      index[i] = bs.index[i];
-    }
-  }
-  
-  template<class IndexType>
-  forceinline
-  BitSet<IndexType>::BitSet(Space&, const TinyBitSet<1U>&) {
-    GECODE_NEVER;
-  }
-  template<class IndexType>
-  forceinline
-  BitSet<IndexType>::BitSet(Space&, const TinyBitSet<2U>&) {
-    GECODE_NEVER;
-  }
-  template<class IndexType>
-  forceinline
-  BitSet<IndexType>::BitSet(Space&, const TinyBitSet<3U>&) {
-    GECODE_NEVER;
-  }
-  template<class IndexType>
-  forceinline
-  BitSet<IndexType>::BitSet(Space&, const TinyBitSet<4U>&) {
-    GECODE_NEVER;
-  }
-
-  template<class IndexType>
-  forceinline void
-  BitSet<IndexType>::replace_and_decrease(IndexType i, BitSetData w) {
-    assert(_limit > 0U);
-    BitSetData w_i = bits[i];
-    if (w != w_i) {
-      bits[i] = w;
-      if (w.none()) {
-        assert(bits[i].none());
-        bits[i] = bits[_limit-1];
-        index[i] = index[_limit-1];
-        _limit--;
-      }
-    }
-  }
-
-  template<class IndexType>
-  forceinline void
-  BitSet<IndexType>::clear_mask(BitSetData* mask) const {
-    assert(_limit > 0U);
-    for (IndexType i = _limit; i--; ) {
-      mask[i].init(false);
-      assert(mask[i].none());
-    }
-  }
-  
-  template<class IndexType>
-  forceinline void
-  BitSet<IndexType>::add_to_mask(const BitSetData* b, BitSetData* mask) const {
-    assert(_limit > 0U);
-    for (IndexType i = _limit; i--; )
-      mask[i] = BitSetData::o(mask[i],b[index[i]]);
-  }
-
-  template<class IndexType>
-  template<bool sparse>
-  forceinline void
-  BitSet<IndexType>::intersect_with_mask(const BitSetData* mask) {
-    assert(_limit > 0U);
-    if (sparse) {
-      for (IndexType i = _limit; i--; ) {
-        assert(!bits[i].none());
-        BitSetData w_i = bits[i];
-        BitSetData w_a = BitSetData::a(w_i, mask[index[i]]);
-        replace_and_decrease(i,w_a);
-        assert(i == _limit || !bits[i].none());
-      }
-    } else { // The same except different indexing in mask
-      for (IndexType i = _limit; i--; ) {
-        assert(!bits[i].none());
-        BitSetData w_i = bits[i];
-        BitSetData w_a = BitSetData::a(w_i, mask[i]);
-        replace_and_decrease(i,w_a);
-        assert(i == _limit || !bits[i].none());
-      }
-    }
-  }
-  
-  template<class IndexType>
-  forceinline void
-  BitSet<IndexType>::intersect_with_masks(const BitSetData* a,
-                                          const BitSetData* b) {
-    assert(_limit > 0U);
-    for (IndexType i = _limit; i--; ) {
-      assert(!bits[i].none());
-      BitSetData w_i = bits[i];
-      IndexType offset = index[i];
-      BitSetData w_o = BitSetData::o(a[offset], b[offset]);
-      BitSetData w_a = BitSetData::a(w_i,w_o);
-      replace_and_decrease(i,w_a);
-      assert(i == _limit || !bits[i].none());
-    }
-  }
-  
-  template<class IndexType>
-  forceinline void
-  BitSet<IndexType>::nand_with_mask(const BitSetData* b) {
-    assert(_limit > 0U);
-    for (IndexType i = _limit; i--; ) {
-      assert(!bits[i].none());
-      BitSetData w = BitSetData::a(bits[i],~(b[index[i]]));
-      replace_and_decrease(i,w);
-      assert(i == _limit || !bits[i].none());
-    }
-  }
-
-  template<class IndexType>
-  forceinline bool
-  BitSet<IndexType>::intersects(const BitSetData* b) const {
-    for (IndexType i = _limit; i--; )
-      if (!BitSetData::a(bits[i],b[index[i]]).none())
-        return true;
-    return false;
-  }
-  
-  
   template<class IndexType>
   forceinline unsigned int
   BitSet<IndexType>::limit(void) const {
@@ -210,14 +65,190 @@ namespace Gecode { namespace Int { namespace Extensional {
   forceinline unsigned int
   BitSet<IndexType>::width(void) const {
     assert(!empty());
-    IndexType width = index[0];
-    for (IndexType i = _limit; i--; ) {
-      width = std::max(width,index[i]);
-    }
+    IndexType width = _index[0];
+    for (IndexType i=1; i<_limit; i++)
+      width = std::max(width,_index[i]);
     assert(static_cast<unsigned int>(width+1U) >= words());
     return static_cast<unsigned int>(width+1U);
   }
 
+  template<class IndexType>
+  forceinline
+  BitSet<IndexType>::BitSet(Space& home, unsigned int n)
+    : _limit(static_cast<IndexType>(n)), 
+      _index(home.alloc<IndexType>(n)),
+      _bits(home.alloc<BitSetData>(n)) {
+    // Set all bits in all words (including the last)
+    for (IndexType i=0; i<_limit; i++) {
+      _bits[i].init(true);
+      _index[i] = i;
+    }
+  }
+
+  template<class IndexType>
+  template<class OldIndexType>
+  forceinline
+  BitSet<IndexType>::BitSet(Space& home,
+                            const BitSet<OldIndexType>& bs)
+    : _limit(static_cast<IndexType>(bs._limit)),
+      _index(home.alloc<IndexType>(_limit)),
+      _bits(home.alloc<BitSetData>(_limit)) {
+    assert(_limit > 0U);
+    for (IndexType i=0; i<_limit; i++) {
+      _bits[i] = bs._bits[i];
+      _index[i] = static_cast<IndexType>(bs._index[i]);
+    }
+  }
+
+  template<class IndexType>
+  forceinline void
+  BitSet<IndexType>::flush(void) {
+    _limit = 0U;
+    assert(empty());
+  }
+    
+  template<class IndexType>
+  forceinline
+  BitSet<IndexType>::BitSet(Space&, const TinyBitSet<1U>&) {
+    GECODE_NEVER;
+  }
+  template<class IndexType>
+  forceinline
+  BitSet<IndexType>::BitSet(Space&, const TinyBitSet<2U>&) {
+    GECODE_NEVER;
+  }
+  template<class IndexType>
+  forceinline
+  BitSet<IndexType>::BitSet(Space&, const TinyBitSet<3U>&) {
+    GECODE_NEVER;
+  }
+  template<class IndexType>
+  forceinline
+  BitSet<IndexType>::BitSet(Space&, const TinyBitSet<4U>&) {
+    GECODE_NEVER;
+  }
+
+  template<class IndexType>
+  forceinline void
+  BitSet<IndexType>::replace_and_decrease(IndexType i, BitSetData w) {
+    assert(_limit > 0U);
+    BitSetData w_i = _bits[i];
+    if (w != w_i) {
+      _bits[i] = w;
+      if (w.none()) {
+        assert(_bits[i].none());
+        _limit--;
+        _bits[i] = _bits[_limit];
+        _index[i] = _index[_limit];
+      }
+    }
+  }
+
+  template<class IndexType>
+  forceinline void
+  BitSet<IndexType>::clear_mask(BitSetData* mask) const {
+    assert(_limit > 0U);
+    for (IndexType i=0; i<_limit; i++) {
+      mask[i].init(false);
+      assert(mask[i].none());
+    }
+  }
+  
+  template<class IndexType>
+  forceinline void
+  BitSet<IndexType>::add_to_mask(const BitSetData* b, BitSetData* mask) const {
+    assert(_limit > 0U);
+    for (IndexType i=0; i<_limit; i++)
+      mask[i] = BitSetData::o(mask[i],b[_index[i]]);
+  }
+
+  template<class IndexType>
+  template<bool sparse>
+  forceinline void
+  BitSet<IndexType>::intersect_with_mask(const BitSetData* mask) {
+    assert(_limit > 0U);
+    if (sparse) {
+      for (IndexType i = _limit; i--; ) {
+        assert(!_bits[i].none());
+        BitSetData w_i = _bits[i];
+        BitSetData w_a = BitSetData::a(w_i, mask[_index[i]]);
+        replace_and_decrease(i,w_a);
+        assert(i == _limit || !_bits[i].none());
+      }
+    } else { // The same except different _indexing in mask
+      for (IndexType i = _limit; i--; ) {
+        assert(!_bits[i].none());
+        BitSetData w_i = _bits[i];
+        BitSetData w_a = BitSetData::a(w_i, mask[i]);
+        replace_and_decrease(i,w_a);
+        assert(i == _limit || !_bits[i].none());
+      }
+    }
+  }
+  
+  template<class IndexType>
+  forceinline void
+  BitSet<IndexType>::intersect_with_masks(const BitSetData* a,
+                                          const BitSetData* b) {
+    assert(_limit > 0U);
+    for (IndexType i = _limit; i--; ) {
+      assert(!_bits[i].none());
+      BitSetData w_i = _bits[i];
+      IndexType offset = _index[i];
+      BitSetData w_o = BitSetData::o(a[offset], b[offset]);
+      BitSetData w_a = BitSetData::a(w_i,w_o);
+      replace_and_decrease(i,w_a);
+      assert(i == _limit || !_bits[i].none());
+    }
+  }
+  
+  template<class IndexType>
+  forceinline void
+  BitSet<IndexType>::nand_with_mask(const BitSetData* b) {
+    assert(_limit > 0U);
+    for (IndexType i = _limit; i--; ) {
+      assert(!_bits[i].none());
+      BitSetData w = BitSetData::a(_bits[i],~(b[_index[i]]));
+      replace_and_decrease(i,w);
+      assert(i == _limit || !_bits[i].none());
+    }
+  }
+
+  template<class IndexType>
+  forceinline bool
+  BitSet<IndexType>::intersects(const BitSetData* b) const {
+    for (IndexType i=0; i<_limit; i++)
+      if (!BitSetData::a(_bits[i],b[_index[i]]).none())
+        return true;
+    return false;
+  }
+    
+  template<class IndexType>
+  forceinline unsigned long long int
+  BitSet<IndexType>::ones(const BitSetData* b) const {
+    unsigned long long int o = 0U;
+    for (IndexType i=0; i<_limit; i++)
+      o += static_cast<unsigned long long int>
+        (BitSetData::a(_bits[i],b[_index[i]]).ones());
+    return o;
+  }
+    
+  template<class IndexType>
+  forceinline unsigned long long int
+  BitSet<IndexType>::ones(void) const {
+    unsigned long long int o = 0U;
+    for (IndexType i=0; i<_limit; i++)
+      o += static_cast<unsigned long long int>(_bits[i].ones());
+    return o;
+  }
+    
+  template<class IndexType>
+  forceinline unsigned long long int
+  BitSet<IndexType>::bits(void) const {
+    return (static_cast<unsigned long long int>(_limit) *
+            static_cast<unsigned long long int>(BitSetData::bpb));
+  }
+
 }}}
 
 // STATISTICS: int-prop
