@@ -148,9 +148,12 @@ namespace Gecode { namespace Int { namespace Extensional {
 
 namespace Gecode {
 
-  DFA::DFA(int start, Transition t_spec[], int f_spec[], bool minimize) {
+  void
+  DFA::init(int start, Transition t_spec[], int f_spec[], bool minimize) {
     using namespace Int;
     using namespace Extensional;
+    Region region;
+
     // Compute number of states and transitions
     int n_states = start;
     int n_trans  = 0;
@@ -164,14 +167,14 @@ namespace Gecode {
     n_states++;
 
     // Temporary structure for transitions
-    Transition* trans = heap.alloc<Transition>(n_trans);
-    for (int i = n_trans; i--; )
+    Transition* trans = region.alloc<Transition>(n_trans);
+    for (int i=0; i<n_trans; i++)
       trans[i] = t_spec[i];
     // Temporary structures for finals
-    int* final = heap.alloc<int>(n_states+1);
-    bool* is_final = heap.alloc<bool>(n_states+1);
+    int* final = region.alloc<int>(n_states+1);
+    bool* is_final = region.alloc<bool>(n_states+1);
     int n_finals = 0;
-    for (int i = n_states+1; i--; )
+    for (int i=0; i<n_states+1; i++)
       is_final[i] = false;
     for (int* f = &f_spec[0]; *f != -1; f++) {
       is_final[*f]      = true;
@@ -181,7 +184,7 @@ namespace Gecode {
     if (minimize) {
       // Sort transitions by symbol and i_state
       TransBySymbolI_State::sort(trans, n_trans);
-      Transition** idx = heap.alloc<Transition*>(n_trans+1);
+      Transition** idx = region.alloc<Transition*>(n_trans+1);
       //  idx[i]...idx[i+1]-1 gives where transitions for symbol i start
       int n_symbols = 0;
       {
@@ -196,11 +199,11 @@ namespace Gecode {
         assert(j == n_trans);
       }
       // Map states to groups
-      int* s2g = heap.alloc<int>(n_states+1);
-      StateGroup* part = heap.alloc<StateGroup>(n_states+1);
-      GroupStates* g2s = heap.alloc<GroupStates>(n_states+1);
+      int* s2g = region.alloc<int>(n_states+1);
+      StateGroup* part = region.alloc<StateGroup>(n_states+1);
+      GroupStates* g2s = region.alloc<GroupStates>(n_states+1);
       // Initialize: final states is group one, all other group zero
-      for (int i = n_states+1; i--; ) {
+      for (int i=0; i<n_states+1; i++) {
         part[i].state = i;
         part[i].group = is_final[i] ? 1 : 0;
         s2g[i]        = part[i].group;
@@ -286,10 +289,10 @@ namespace Gecode {
               break;
             }
         // Compute representatives
-        int* s2r = heap.alloc<int>(n_states+1);
-        for (int i = n_states+1; i--; )
+        int* s2r = region.alloc<int>(n_states+1);
+        for (int i=0; i<n_states+1; i++)
           s2r[i] = -1;
-        for (int g = n_groups; g--; )
+        for (int g=0; g<n_groups; g++)
           s2r[g2s[g].fst->state] = g;
         // Clean transitions
         int j = 0;
@@ -302,21 +305,16 @@ namespace Gecode {
           }
         n_trans  = j;
         n_states = n_groups;
-        heap.free<int>(s2r,n_states+1);
       }
-      heap.free<GroupStates>(g2s,n_states+1);
-      heap.free<StateGroup>(part,n_states+1);
-      heap.free<int>(s2g,n_states+1);
-      heap.free<Transition*>(idx,n_trans+1);
     }
 
     // Do a reachability analysis for all states starting from start state
-    Gecode::Support::StaticStack<int,Heap> visit(heap,n_states);
-    int* state = heap.alloc<int>(n_states);
-    for (int i=n_states; i--; )
+    Gecode::Support::StaticStack<int,Region> visit(region,n_states);
+    int* state = region.alloc<int>(n_states);
+    for (int i=0; i<n_states; i++)
       state[i] = SI_NONE;
 
-    Transition** idx = heap.alloc<Transition*>(n_states+1);
+    Transition** idx = region.alloc<Transition*>(n_states+1);
     {
       // Sort all transitions according to i_state and create index structure
       //  idx[i]...idx[i+1]-1 gives where transitions for state i start
@@ -360,7 +358,7 @@ namespace Gecode {
         assert(j == n_trans);
       }
 
-      for (int i = n_finals; i--; ) {
+      for (int i=0; i<n_finals; i++) {
         state[final[i]] |= (SI_TO_FINAL | SI_FINAL);
         visit.push(final[i]);
       }
@@ -373,13 +371,10 @@ namespace Gecode {
           }
       }
     }
-    heap.free<Transition*>(idx,n_states+1);
-    heap.free<int>(final,n_states+1);
-    heap.free<bool>(is_final,n_states+1);
 
     // Now all reachable states are known (also the final ones)
-    int* re = heap.alloc<int>(n_states);
-    for (int i = n_states; i--; )
+    int* re = region.alloc<int>(n_states);
+    for (int i=0; i<n_states; i++)
       re[i] = -1;
 
     // Renumber states
@@ -388,7 +383,7 @@ namespace Gecode {
     re[start] = m_states++;
 
     // Renumber final states
-    for (int i = n_states; i--; )
+    for (int i=n_states; i--; )
       if ((state[i] == (SI_FINAL | SI_FROM_START | SI_TO_FINAL)) && (re[i] < 0))
         re[i] = m_states++;
     // If start state is final, final states start from zero, otherwise from one
@@ -397,13 +392,13 @@ namespace Gecode {
     // final_fst...final_lst-1 are the final states
 
     // Renumber remaining states
-    for (int i = n_states; i--; )
+    for (int i=n_states; i--; )
       if ((state[i] == (SI_FROM_START | SI_TO_FINAL)) && (re[i] < 0))
         re[i] = m_states++;
 
     // Count number of remaining transitions
     int m_trans = 0;
-    for (int i = n_trans; i--; )
+    for (int i=n_trans; i--; )
       if ((re[trans[i].i_state] >= 0) && (re[trans[i].o_state] >= 0))
         m_trans++;
 
@@ -439,26 +434,24 @@ namespace Gecode {
     {
       // Compute maximal degree
       unsigned int max_degree = 0;
-      unsigned int* deg = heap.alloc<unsigned int>(m_states);
+      unsigned int* deg = region.alloc<unsigned int>(m_states);
 
       // Compute in-degree per state
-      for (int i = m_states; i--; )
+      for (int i=0; i<m_states; i++)
         deg[i] = 0;
-      for (int i = m_trans; i--; )
+      for (int i=0; i<m_trans; i++)
         deg[d->trans[i].o_state]++;
-      for (int i = m_states; i--; )
+      for (int i=0; i<m_states; i++)
         max_degree = std::max(max_degree,deg[i]);
 
       // Compute out-degree per state
-      for (int i = m_states; i--; )
+      for (int i=0; i<m_states; i++)
         deg[i] = 0;
-      for (int i = m_trans; i--; )
+      for (int i=0; i<m_trans; i++)
         deg[d->trans[i].i_state]++;
-      for (int i = m_states; i--; )
+      for (int i=0; i<m_states; i++)
         max_degree = std::max(max_degree,deg[i]);
 
-      heap.free<unsigned int>(deg,m_states);
-
       // Compute transitions per symbol
       {
         int i=0;
@@ -476,9 +469,32 @@ namespace Gecode {
 
     d->fill();
     object(d);
-    heap.free<int>(re,n_states);
-    heap.free<int>(state,n_states);
-    heap.free<Transition>(trans,n_trans);
+  }
+
+  DFA::DFA(int start, Transition t_spec[], int f_spec[], bool minimize) {
+    init(start,t_spec,f_spec,minimize);
+  }
+
+  DFA::DFA(int start, std::initializer_list<Transition> tl,
+           std::initializer_list<int> fl, bool minimize) {
+    Region reg;
+    int nt = static_cast<int>(tl.size());
+    int nf = static_cast<int>(fl.size());
+    Transition* ts = reg.alloc<Transition>(nt + 1);
+    {
+      int i=0;
+      for (const Transition& t : tl)
+        ts[i++] = t;
+      ts[nt].i_state = -1;
+    }
+    int* fs = reg.alloc<int>(nf + 1);
+    {
+      int i=0;
+      for (const int& f : fl)
+        fs[i++] = f;
+      fs[nf] = -1;
+    }
+    init(start,ts,fs,minimize);
   }
 
   bool
