@@ -12,10 +12,6 @@
  *     Christian Schulte, 2009
  *     Guido Tack, 2009
  *
- *  Last modified:
- *     $Date$ by $Author$
- *     $Revision$
- *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
  *     http://www.gecode.org
@@ -1341,9 +1337,10 @@ namespace Gecode { namespace Int { namespace GCC {
           Edge*  mlb = vrn->get_match(LBC);
           Edge** p   = vrn->adj();
           Edge*  e   = *p;
+          GECODE_ASSUME(e != NULL);
           do {
             // search the edge that has to be deleted
-            while (e != NULL && (e->getVal()->val < xiter.val())) {
+            while ((e != NULL) && (e->getVal()->val < xiter.val())) {
               // Skip edge
               e->getVal()->noe--;
               vrn->noe--;
@@ -1352,6 +1349,7 @@ namespace Gecode { namespace Int { namespace GCC {
               e = e ->next();
               *p = e;
             }
+            GECODE_ASSUME(e != NULL);
 
             assert(xiter.val() == e->getVal()->val);
 
@@ -1363,7 +1361,7 @@ namespace Gecode { namespace Int { namespace GCC {
             e = e->next();
           } while (xiter());
           *p = NULL;
-          while (e) {
+          while (e != NULL) {
             e->getVar()->noe--;
             e->getVal()->noe--;
             e->del_edge();
