@@ -441,8 +441,8 @@ namespace Gecode { namespace Int { namespace Linear {
       // Check whether current assignment is solution
       if (d == 0) {
         // Record support
-        for (int is=n; is--; ) xp[is].support();
-        for (int js=m; js--; ) yp[js].support();
+        for (int is=0; is<n; is++) xp[is].support();
+        for (int js=0; js<m; js++) yp[js].support();
       }
     prev_j:
       // Try iterating to next assignment: negative views
@@ -460,12 +460,12 @@ namespace Gecode { namespace Int { namespace Linear {
 
     // Tell back new variable domains
     bool assigned = true;
-    for (int i=n; i--; ) {
+    for (int i=0; i<n; i++) {
       GECODE_ME_CHECK(xp[i].tell(home));
       if (!x[i].assigned())
         assigned = false;
     }
-    for (int j=m; j--; ) {
+    for (int j=0; j<m; j++) {
       GECODE_ME_CHECK(yp[j].tell(home));
       if (!y[j].assigned())
         assigned = false;
