@@ -297,11 +297,11 @@ namespace Gecode { namespace Int {
     }
   }
 
+
   /*
    * Cache operations
    *
    */
-
   template<class View>
   void
   CachedView<View>::initCache(Space& home, const IntSet& s) {
@@ -398,14 +398,13 @@ namespace Gecode { namespace Int {
    */
   template<class View>
   forceinline bool
-  same(const CachedView<View>& x, const CachedView<View>& y) {
-    return same(x.base(),y.base()) && (x.offset() == y.offset());
+  operator ==(const CachedView<View>& x, const CachedView<View>& y) {
+    return (x.base() == y.base()) && (x.offset() == y.offset());
   }
   template<class View>
   forceinline bool
-  before(const CachedView<View>& x, const CachedView<View>& y) {
-    return before(x.base(),y.base())
-      || (same(x.base(),y.base()) && (x.offset() < y.offset()));
+  operator !=(const CachedView<View>& x, const CachedView<View>& y) {
+    return !(x == y);
   }
 
 }}
