@@ -309,6 +309,19 @@ namespace Gecode { namespace Int {
     return r.min() + static_cast<int>(i);
   }
 
+  /*
+   * View comparison
+   *
+   */
+  forceinline bool
+  operator ==(const MinusView& x, const MinusView& y) {
+    return x.base() == y.base();
+  }
+  forceinline bool
+  operator !=(const MinusView& x, const MinusView& y) {
+    return !(x == y);
+  }
+
 }}
 
 // STATISTICS: int-var
