@@ -265,6 +265,17 @@ namespace Gecode { namespace Int {
   }
 
 
+  /*
+   * Ordering
+   *
+   */
+  forceinline bool
+  OffsetView::operator <(const OffsetView& y) const {
+    return ((base() < y.base())
+            || ((base() == y.base()) && (offset() < y.offset())));
+  }
+
+
   /**
    * \brief %Range iterator for offset integer views
    * \ingroup TaskActorIntView
@@ -304,13 +315,12 @@ namespace Gecode { namespace Int {
    *
    */
   forceinline bool
-  same(const OffsetView& x, const OffsetView& y) {
-    return same(x.base(),y.base()) && (x.offset() == y.offset());
+  operator ==(const OffsetView& x, const OffsetView& y) {
+    return (x.base() == y.base()) && (x.offset() == y.offset());
   }
   forceinline bool
-  before(const OffsetView& x, const OffsetView& y) {
-    return before(x.base(),y.base())
-      || (same(x.base(),y.base()) && (x.offset() < y.offset()));
+  operator !=(const OffsetView& x, const OffsetView& y) {
+    return !(x == y);
   }
 
 }}
