@@ -231,6 +231,19 @@ namespace Gecode { namespace Int {
   }
 
 
+  /*
+   * Ordering
+   *
+   */
+  template<class Val, class UnsVal>
+  forceinline bool
+  ScaleView<Val,UnsVal>::operator <(const ScaleView<Val,UnsVal>& y) const {
+    return ((base() < y.base())
+            || ((base() == y.base()) && (scale() < y.scale())));
+  }
+
+
+
 
   /**
    * \brief %Range iterator for integer-precision scale integer views
@@ -309,14 +322,13 @@ namespace Gecode { namespace Int {
    */
   template<class Val, class UnsVal>
   forceinline bool
-  same(const ScaleView<Val,UnsVal>& x, const ScaleView<Val,UnsVal>& y) {
-    return same(x.base(),y.base()) && (x.scale() == y.scale());
+  operator ==(const ScaleView<Val,UnsVal>& x, const ScaleView<Val,UnsVal>& y) {
+    return (x.base() == y.base()) && (x.scale() == y.scale());
   }
   template<class Val, class UnsVal>
   forceinline bool
-  before(const ScaleView<Val,UnsVal>& x, const ScaleView<Val,UnsVal>& y) {
-    return before(x.base(),y.base())
-      || (same(x.base(),y.base()) && (x.scale() < y.scale()));
+  operator !=(const ScaleView<Val,UnsVal>& x, const ScaleView<Val,UnsVal>& y) {
+    return !(x == y);
   }
 
 }}
