@@ -133,6 +133,7 @@ namespace Gecode {
       pc.p.queue[i].init();
     pc.p.bid_sc = (reserved_bid+1) << sc_bits;
     pc.p.n_sub  = 0;
+    pc.p.vti.other();
   }
 
   void
@@ -228,6 +229,25 @@ namespace Gecode {
     return nullptr;
   }
 
+  void
+  Space::post(const PostInfo& pi) {
+    assert(pc.p.bid_sc & sc_trace);
+    TraceRecorder* tr = findtracerecorder();
+    if ((tr != NULL) && (tr->events() & TE_POST)) {
+      GECODE_ASSUME(ssd.data().gpi.pid() >= pi.pid);
+      unsigned int n = ssd.data().gpi.pid() - pi.pid;
+      PostTraceInfo::Status s;
+      if (failed())
+        s = PostTraceInfo::FAILED;
+      else if (n == 0)
+        s = PostTraceInfo::SUBSUMED;
+      else
+        s = PostTraceInfo::POSTED;
+      PostTraceInfo pti(pi.pg,s,n);
+      tr->tracer()._post(*this,pti);
+    }
+  }
+
   SpaceStatus
   Space::status(StatusStatistics& stat) {
     // Check whether space is failed
@@ -364,8 +384,6 @@ namespace Gecode {
       d_stable: ;
       } else {
         // Support disabled propagators and tracing
-        // Find a non-disabled tracer recorder (possibly null)
-        TraceRecorder* tr = findtracerecorder();
 
 #define GECODE_STATUS_TRACE(q,s) \
   if ((tr != NULL) && (tr->events() & TE_PROPAGATE) && \
@@ -375,7 +393,12 @@ namespace Gecode {
     tr->tracer()._propagate(*this,pti);                \
   }
 
+        // Find a non-disabled tracer recorder (possibly null)
+        TraceRecorder* tr = findtracerecorder();
+        // Remember post information
+        ViewTraceInfo vti(pc.p.vti);
         goto t_unstable;
+
       t_execute:
         stat.propagate++;
         if (p->disabled())
@@ -442,8 +465,11 @@ namespace Gecode {
           GECODE_NEVER;
         }
       t_stable:
-        pc.p.vti.other();
+        // Restore post information
+        pc.p.vti = vti;
+
 #undef GECODE_STATUS_TRACE
+
       }
     }
 
@@ -567,9 +593,10 @@ namespace Gecode {
           CommitTraceInfo cti(*b,c,a);
           tr->tracer()._commit(*this,cti);
         }
+        ViewTraceInfo vti = pc.p.vti;
         pc.p.vti.brancher(*b);
         ExecStatus es = b->commit(*this,c,a);
-        pc.p.vti.other();
+        pc.p.vti = vti;
         if (es == ES_FAILED)
           fail();
       } else {
@@ -597,9 +624,10 @@ namespace Gecode {
           CommitTraceInfo cti(*b,c,a);
           tr->tracer()._commit(*this,cti);
         }
+        ViewTraceInfo vti = pc.p.vti;
         pc.p.vti.brancher(*b);
         ExecStatus es = b->commit(*this,c,a);
-        pc.p.vti.other();
+        pc.p.vti = vti;
         if (es == ES_FAILED)
           fail();
       } else {
@@ -891,9 +919,10 @@ namespace Gecode {
 
 
   Group::Group(void) {
-    m.acquire();
-    gid = next++;
-    m.release();
+    {
+      Support::Lock l(m);
+      gid = next++;
+    }
     if (gid == GROUPID_MAX)
       throw TooManyGroups("Group::Group");
   }
