@@ -37,7 +37,6 @@
  *
  */
 
-#include <cstdarg>
 #include <iostream>
 #include <sstream>
 
@@ -137,6 +136,9 @@ namespace Gecode {
     /// Return number of elements
     int size(void) const;
 
+    /// Test equality with \a sa
+    bool operator ==(const SharedArray<T>& sa) const;
+
     /// \name Array iteration
     //@{
     /// Return an iterator at the beginning of the array
@@ -270,11 +272,25 @@ namespace Gecode {
     return (*static_cast<SAO*>(object()))[i];
   }
 
+  template<class T>
+  inline bool
+  SharedArray<T>::operator ==(const SharedArray<T>& sa) const {
+    if (size() != sa.size())
+      return false;
+    if (object()==sa.object())
+      return true;
+    for (int i=0; i<size(); i++) {
+      if ((*this)[i] != sa[i])
+        return false;
+    }
+    return true;
+  }
+
   template<class T>
   forceinline
   SharedArray<T>::SharedArray(const ArgArrayBase<T>& a)
     : SharedHandle(new SAO(a.size())) {
-    for (int i=a.size(); i--; )
+    for (int i=0; i<a.size(); i++)
       operator [](i)=a[i];
   }
 
