@@ -31,6 +31,8 @@
  *
  */
 
+#include <cstddef>
+
 namespace Gecode {
 
   /**
@@ -58,7 +60,9 @@ namespace Gecode {
       /// Amount of free memory
       size_t free;
       /// The actual memory area (allocated from top to bottom)
-      double area[Kernel::MemoryConfig::region_area_size / sizeof(double)];
+      alignas((alignof(std::max_align_t) > GECODE_MEMORY_ALIGNMENT) ?
+              alignof(std::max_align_t) : GECODE_MEMORY_ALIGNMENT)
+        double area[Kernel::MemoryConfig::region_area_size / sizeof(double)];
       /// A pointer to another chunk
       Chunk* next;
       /// Return memory if available
@@ -328,7 +332,9 @@ namespace Gecode {
    */
   forceinline bool
   Region::Chunk::alloc(size_t s, void*& p) {
-    Kernel::MemoryConfig::align(s);
+    Kernel::MemoryConfig::align
+      (s,((alignof(std::max_align_t) > GECODE_MEMORY_ALIGNMENT) ?
+          alignof(std::max_align_t) : GECODE_MEMORY_ALIGNMENT));
     if (s > free)
       return false;
     free -= s;
@@ -379,7 +385,7 @@ namespace Gecode {
   forceinline T*
   Region::alloc(long unsigned int n) {
     T* p = static_cast<T*>(ralloc(sizeof(T)*n));
-    for (long unsigned int i=n; i--; )
+    for (long unsigned int i=0U; i<n; i++)
       (void) new (p+i) T();
     return p;
   }
@@ -404,7 +410,7 @@ namespace Gecode {
   template<class T>
   forceinline void
   Region::free(T* b, long unsigned int n) {
-    for (long unsigned int i=n; i--; )
+    for (long unsigned int i=0U; i<n; i++)
       b[i].~T();
     rfree(b,n*sizeof(T));
   }
@@ -431,7 +437,7 @@ namespace Gecode {
   Region::realloc(T* b, long unsigned int n, long unsigned int m) {
     if (n < m) {
       T* p = static_cast<T*>(ralloc(sizeof(T)*m));
-      for (long unsigned int i=n; i--; )
+      for (long unsigned int i=0U; i<n; i++)
         (void) new (p+i) T(b[i]);
       for (long unsigned int i=n; i<m; i++)
         (void) new (p+i) T();
