@@ -148,6 +148,7 @@ namespace Gecode {
    */
   class Tracer : public TracerBase {
     friend class Space;
+    friend class PostInfo;
   private:
     /**
      * \brief Propagate function synchronization
@@ -163,6 +164,13 @@ namespace Gecode {
      *
      */
     void _commit(const Space& home, const CommitTraceInfo& cti);
+    /**
+     * \brief Post function synchronization
+     *
+     * Just calls the actual post function protected by a mutex.
+     *
+     */
+    void _post(const Space& home, const PostTraceInfo& pti);
   public:
     /// Constructor
     Tracer(void);
@@ -182,6 +190,14 @@ namespace Gecode {
      */
     virtual void commit(const Space& home,
                         const CommitTraceInfo& cti) = 0;
+    /**
+     * \brief Post function
+     *
+     * The post function is called when an attempt to post a propagator
+     * has been executed.
+     */
+    virtual void post(const Space& home,
+                      const PostTraceInfo& pti) = 0;
     /// Destructor
     virtual ~Tracer(void);
   };
@@ -214,6 +230,14 @@ namespace Gecode {
      */
     virtual void commit(const Space& home,
                         const CommitTraceInfo& cti);
+    /**
+     * \brief Post function
+     *
+     * The post function is called when an attempt to post a propagator
+     * has been executed.
+     */
+    virtual void post(const Space& home,
+                      const PostTraceInfo& pti);
     /// Default tracer (printing to std::cerr)
     static StdTracer def;
   };
@@ -232,9 +256,8 @@ namespace Gecode {
   forceinline void
   ViewTracer<View>::_init(const Space& home,
                           const ViewTraceRecorder<View>& t) {
-    m.acquire();
+    Support::Lock l(m);
     init(home,t);
-    m.release();
   }
   template<class View>
   forceinline void
@@ -242,33 +265,29 @@ namespace Gecode {
                            const ViewTraceRecorder<View>& t,
                            const ViewTraceInfo& vti,
                            int i, typename TraceTraits<View>::TraceDelta& d) {
-    m.acquire();
+    Support::Lock l(m);
     prune(home,t,vti,i,d);
-    m.release();
   }
   template<class View>
   forceinline void
   ViewTracer<View>::_fail(const Space& home,
                           const ViewTraceRecorder<View>& t) {
-    m.acquire();
+    Support::Lock l(m);
     fail(home,t);
-    m.release();
   }
   template<class View>
   forceinline void
   ViewTracer<View>::_fix(const Space& home,
                          const ViewTraceRecorder<View>& t) {
-    m.acquire();
+    Support::Lock l(m);
     fix(home,t);
-    m.release();
   }
   template<class View>
   forceinline void
   ViewTracer<View>::_done(const Space& home,
                           const ViewTraceRecorder<View>& t) {
-    m.acquire();
+    Support::Lock l(m);
     done(home,t);
-    m.release();
   }
 
   template<class View>
@@ -288,16 +307,20 @@ namespace Gecode {
   forceinline void
   Tracer::_propagate(const Space& home,
                      const PropagateTraceInfo& pti) {
-    m.acquire();
+    Support::Lock l(m);
     propagate(home,pti);
-    m.release();
   }
   forceinline void
   Tracer::_commit(const Space& home,
                   const CommitTraceInfo& cti) {
-    m.acquire();
+    Support::Lock l(m);
     commit(home,cti);
-    m.release();
+  }
+  forceinline void
+  Tracer::_post(const Space& home,
+                const PostTraceInfo& pti) {
+    Support::Lock l(m);
+    post(home,pti);
   }
 
   forceinline
