@@ -76,14 +76,6 @@ namespace Gecode {
     /// Update this variable to be a clone of variable \a y
     void update(Space& home, VarImpVar<VarImp>& y);
     //@}
-
-    /// \name Variable comparison
-    //@{
-    /// Test whether variable is the same as \a y
-    bool same(const VarImpVar<VarImp>& y) const;
-    /// Test whether variable comes before \a y (arbitrary order)
-    bool before(const VarImpVar<VarImp>& y) const;
-    //@}
   };
 
 
@@ -124,16 +116,6 @@ namespace Gecode {
   VarImpVar<VarImp>::update(Space& home, VarImpVar<VarImp>& y) {
     x = y.x->copy(home);
   }
-  template<class VarImp>
-  forceinline bool
-  VarImpVar<VarImp>::same(const VarImpVar<VarImp>& y) const {
-    return varimp() == y.varimp();
-  }
-  template<class VarImp>
-  forceinline bool
-  VarImpVar<VarImp>::before(const VarImpVar<VarImp>& y) const {
-    return varimp() < y.varimp();
-  }
 
 }
 
