@@ -67,13 +67,15 @@ namespace Gecode {
   }
 
   forceinline void
-  LinIntRel::post(Home home, bool t, IntPropLevel ipl) const {
-    e.post(home,t ? irt : neg(irt),ipl);
+  LinIntRel::post(Home home, bool t,
+                  const IntPropLevels& ipls) const {
+    e.post(home,t ? irt : neg(irt),ipls);
   }
 
   forceinline void
-  LinIntRel::post(Home home, const BoolVar& b, bool t, IntPropLevel ipl) const {
-    e.post(home,t ? irt : neg(irt),b,ipl);
+  LinIntRel::post(Home home, const BoolVar& b, bool t,
+                  const IntPropLevels& ipls) const {
+    e.post(home,t ? irt : neg(irt),b,ipls);
   }
 
 }
