@@ -39,7 +39,7 @@ namespace Gecode {
   IntMinimizeSpace::constrain(const Space& _best) {
     const IntMinimizeSpace* best =
       dynamic_cast<const IntMinimizeSpace*>(&_best);
-    if (best == NULL)
+    if (best == nullptr)
       throw DynamicCastFailed("IntMinimizeSpace::constrain");
     rel(*this, cost(), IRT_LE, best->cost().val());
   }
@@ -49,7 +49,7 @@ namespace Gecode {
   IntMaximizeSpace::constrain(const Space& _best) {
     const IntMaximizeSpace* best =
       dynamic_cast<const IntMaximizeSpace*>(&_best);
-    if (best == NULL)
+    if (best == nullptr)
       throw DynamicCastFailed("IntMaximizeSpace::constrain");
     rel(*this, cost(), IRT_GR, best->cost().val());
   }
@@ -59,7 +59,7 @@ namespace Gecode {
   IntLexMinimizeSpace::constrain(const Space& _best) {
     const IntLexMinimizeSpace* best =
       dynamic_cast<const IntLexMinimizeSpace*>(&_best);
-    if (best == NULL)
+    if (best == nullptr)
       throw DynamicCastFailed("IntLexMinimizeSpace::constrain");
     IntVarArgs cx(cost()), bx(best->cost());
     IntArgs bn(bx.size());
@@ -72,7 +72,7 @@ namespace Gecode {
   IntLexMaximizeSpace::constrain(const Space& _best) {
     const IntLexMaximizeSpace* best =
       dynamic_cast<const IntLexMaximizeSpace*>(&_best);
-    if (best == NULL)
+    if (best == nullptr)
       throw DynamicCastFailed("IntLexMaximizeSpace::constrain");
     IntVarArgs cx(cost()), bx(best->cost());
     IntArgs bn(bx.size());
@@ -87,7 +87,7 @@ namespace Gecode {
   FloatMinimizeSpace::constrain(const Space& _best) {
     const FloatMinimizeSpace* best =
       dynamic_cast<const FloatMinimizeSpace*>(&_best);
-    if (best == NULL)
+    if (best == nullptr)
       throw DynamicCastFailed("FloatMinimizeSpace::constrain");
     rel(*this, cost(), FRT_LE, best->cost().val()-step);
   }
@@ -97,7 +97,7 @@ namespace Gecode {
   FloatMaximizeSpace::constrain(const Space& _best) {
     const FloatMaximizeSpace* best =
       dynamic_cast<const FloatMaximizeSpace*>(&_best);
-    if (best == NULL)
+    if (best == nullptr)
       throw DynamicCastFailed("FloatMaximizeSpace::constrain");
     rel(*this, cost(), FRT_GR, best->cost().val()+step);
   }
