@@ -41,7 +41,7 @@ namespace Gecode {
    */
 
   forceinline
-  SetExpr::SetExpr(void) : n(NULL) {}
+  SetExpr::SetExpr(void) : n(nullptr) {}
 
 }
 
