@@ -203,7 +203,7 @@ namespace Gecode { namespace Set { namespace RelOp {
   forceinline
   UnionN<View0,View1>::UnionN(Home home, ViewArray<View0>& x, View1 y)
     : MixNaryOnePropagator<View0,PC_SET_ANY,View1,PC_SET_ANY>(home,x,y) {
-    shared = x.shared() || viewarrayshared(x,y);
+    shared = Gecode::shared(x) || viewarrayshared(x,y);
   }
 
   template<class View0, class View1>
@@ -211,7 +211,7 @@ namespace Gecode { namespace Set { namespace RelOp {
   UnionN<View0,View1>::UnionN(Home home, ViewArray<View0>& x,
                               const IntSet& z, View1 y)
     : MixNaryOnePropagator<View0,PC_SET_ANY,View1,PC_SET_ANY>(home,x,y) {
-    shared = x.shared() || viewarrayshared(x,y);
+    shared = Gecode::shared(x) || viewarrayshared(x,y);
     IntSetRanges rz(z);
     unionOfDets.includeI(home, rz);
   }
