@@ -676,41 +676,65 @@ namespace Gecode { namespace Set {
     //@}
   };
 
+  forceinline bool
+  ConstSetView::operator <(const ConstSetView& y) const {
+    if (size < y.size)
+      return true;
+    if (size > y.size)
+      return false;
+    if (domSize < y.domSize)
+      return true;
+    if (domSize > y.domSize)
+      return false;
+    for (int i=size; i--; ) {
+      if (ranges[2*i] < y.ranges[2*i])
+        return true;
+      if (ranges[2*i] > y.ranges[2*i])
+        return false;
+      if (ranges[2*i+1] < y.ranges[2*i+1])
+        return true;
+      if (ranges[2*i+1] > y.ranges[2*i+1])
+        return false;
+    }
+    return false;
+  }
+
   /*
    * Testing
    *
    */
   forceinline bool
-  same(const ConstSetView& x, const ConstSetView& y) {
+  operator ==(const ConstSetView& x, const ConstSetView& y) {
     if ((x.size != y.size) || (x.domSize != y.domSize))
       return false;
     for (int i=x.size; i--; )
-      if (x.ranges[2*i]   != y.ranges[2*i] ||
-          x.ranges[2*i+1] != y.ranges[2*i+1])
+      if ((x.ranges[2*i]   != y.ranges[2*i]) ||
+          (x.ranges[2*i+1] != y.ranges[2*i+1]))
         return false;
     return true;
   }
   forceinline bool
-  before(const ConstSetView& x, const ConstSetView& y) {
-    if (x.size < y.size)
-      return true;
-    if (x.domSize < y.domSize)
-      return true;
-    for (int i=x.size; i--; )
-      if (x.ranges[2*i]   < y.ranges[2*i] ||
-          x.ranges[2*i+1] < y.ranges[2*i+1])
-        return true;
+  operator !=(const ConstSetView& x, const ConstSetView& y) {
+    return !(x == y);
+  }
+
+
+  forceinline bool
+  operator ==(const EmptyView&, const EmptyView&) {
+    return true;
+  }
+  forceinline bool
+  operator !=(const EmptyView&, const EmptyView&) {
     return false;
   }
 
-
   forceinline bool
-  same(const EmptyView&, const EmptyView&) {
+  operator ==(const UniverseView&, const UniverseView&) {
     return true;
   }
   forceinline bool
-  same(const UniverseView&, const UniverseView&) {
-    return true;
+  operator !=(const UniverseView&, const UniverseView&) {
+    return false;
   }
 
 }}
